local folder, core = ...

if not core.LibNameplate then
	return
end

--Globals
local pairs = pairs

-- Isolate the environment
--~ setfenv(1, core)
-- local

local defaultSettings = core.defaultSettings
local L = core.L or LibStub("AceLocale-3.0"):GetLocale(folder, true)

local P = {}
local prev_OnEnable = core.OnEnable;
function core:OnEnable()
	prev_OnEnable(self);
	
--~ 	self:Debug("OnEnable", "options", self.db.profile)
	P = self.db.profile
end



local CoreOptionsTable = {
	name = core.titleFull,
	type = "group",
	childGroups = "tab",

	args = {
		core={
			name = L["Core"],
			type = "group",
			order = 1,
			args={}
		},

		who={
			name = L["Who"],
			type = "group",
			order = 2,
			args={}
		},
		
		bar = {
			name = L["Bar"],
			type = "group",
			order = 3,
			args={}
		},
	},
}

-- CORE TAB
CoreOptionsTable.args.core.args.enable = {
	type = "toggle",	order	= 1,
	name	= L["Enable"],
	desc	= L["Enables / Disables the addon"],
	set = function(info,val) 
		if val == true then
			core:Enable()
		else
			core:Disable()
		end
	end,
	get = function(info) return core:IsEnabled() end
}



defaultSettings.profile.defaultSpells		= 1
CoreOptionsTable.args.core.args.defaultSpells = {
	name = L["Show by default"],
	order = 10,
	desc = L["spells to show by default"],
	type = "select",
	
	values = function()
		return {
			L["All"], 
			L["Mine Only"],
			L["None"],
		}
	end,
	set = function(info,val) 
		P.defaultSpells = val
	end,
	get = function(info) return P.defaultSpells end
}



defaultSettings.profile.unknownSpellDataIcon		= true
CoreOptionsTable.args.core.args.unknownSpellDataIcon = {
	name = L["Unknown spell info"],
	desc = L["Display a question mark above plates we don't know spells for. Target or mouseover those plates."],
	type = "toggle",
	order	= 11,
	set = function(info,val) 
		P.unknownSpellDataIcon = val
	end,
	get = function(info) return P.unknownSpellDataIcon end
}

defaultSettings.profile.showBuffs		= true
CoreOptionsTable.args.core.args.showBuffs = {
	name = L["Show Buffs"],
	desc = L["Show buffs above nameplate."],
	type = "toggle",
	order	= 12,
	set = function(info,val) 
		P.showBuffs = val
	end,
	get = function(info) return P.showBuffs end
}

defaultSettings.profile.showDefuffs		= true
CoreOptionsTable.args.core.args.showDefuffs = {
	name = L["Show Debuffs"],
	desc = L["Show debuffs above nameplate."],
	type = "toggle",
	order	= 13,
	set = function(info,val) 
		P.showDefuffs = val
	end,
	get = function(info) return P.showDefuffs end
}

defaultSettings.profile.showAura		= false
CoreOptionsTable.args.core.args.showAura = {
	name = L["Show Aura"],
	desc = L["Show auras above nameplate. This sometimes causes duplicate buffs."],
	type = "toggle",
	order	= 14,
	set = function(info,val) 
		P.showAura = val
	end,
	get = function(info) return P.showAura end
}

--END CORE TAB

--   WHO TAB
CoreOptionsTable.args.who.args.typeHeader = {
	name	= L["Type"],
	order	= 10,
	type = "header",
}

defaultSettings.profile.abovePlayers		= true
CoreOptionsTable.args.who.args.abovePlayers = {
	name = L["Players"],
	desc = L["Add buffs above players"],
	type = "toggle",
	order	= 11,
	set = function(info,val) 
		P.abovePlayers = val
	end,
	get = function(info) return P.abovePlayers end
}

defaultSettings.profile.aboveNPC		= true
CoreOptionsTable.args.who.args.aboveNPC = {
	name = L["NPC"],
	desc = L["Add buffs above NPCs"],
	type = "toggle",
	order	= 12,
	set = function(info,val) 
		P.aboveNPC = val
	end,
	get = function(info) return P.aboveNPC end
}

CoreOptionsTable.args.who.args.reactionHeader = {
	name	= L["Reaction"],
	order	= 15,
	type = "header",
}

defaultSettings.profile.aboveFriendly		= true
CoreOptionsTable.args.who.args.aboveFriendly = {
	name = L["Friendly"],
	desc = L["Add buffs above friendly plates"],
	type = "toggle",
	order	= 16,
	set = function(info,val) 
		P.aboveFriendly = val
	end,
	get = function(info) return P.aboveFriendly end
}

defaultSettings.profile.aboveNeutral		= true
CoreOptionsTable.args.who.args.aboveNeutral = {
	name = L["Neutral"],
	desc = L["Add buffs above neutral plates"],
	type = "toggle",
	order	= 17,
	set = function(info,val) 
		P.aboveNeutral = val
	end,
	get = function(info) return P.aboveNeutral end
}

defaultSettings.profile.aboveHostile		= true
CoreOptionsTable.args.who.args.aboveHostile = {
	name = L["Hostile"],
	desc = L["Add buffs above hostile plates"],
	type = "toggle",
	order	= 18,
	set = function(info,val) 
		P.aboveHostile = val
	end,
	get = function(info) return P.aboveHostile end
}

--   END WHO TAB

defaultSettings.profile.barAnchorPoint		= "BOTTOM"
CoreOptionsTable.args.bar.args.barAnchorPoint = {
	name = L["Bar Anchor Point"],
	order = 1,
	desc = L["Point of the buff frame that gets anchored to the nameplate.\ndefault = Bottom"],
	type = "select",
	
	values = function()
		return {
			["TOP"]=L["Top"], 
			["BOTTOM"]=L["Bottom"], 
			["LEFT"]=L["Left"], 
			["RIGHT"]=L["Right"], 
			["CENTER"]=L["Center"], 
			["TOPLEFT"]=L["Top Left"], 
			["BOTTOMLEFT"]=L["Bottom Left"], 
			["TOPRIGHT"]=L["Top Right"], 
			["BOTTOMRIGHT"]=L["Bottom Right"], 
		}
	end,
	set = function(info,val) 
		P.barAnchorPoint = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.barAnchorPoint end
}

defaultSettings.profile.plateAnchorPoint		= "TOP"
CoreOptionsTable.args.bar.args.plateAnchorPoint = {
	name = L["Plate Anchor Point"],
	order = 2,
	desc = L["Point of the nameplate our buff frame gets anchored to.\ndefault = Top"],
	type = "select",
	
	values = function()
		return {
			["TOP"]=L["Top"], 
			["BOTTOM"]=L["Bottom"], 
			["LEFT"]=L["Left"], 
			["RIGHT"]=L["Right"], 
			["CENTER"]=L["Center"], 
			["TOPLEFT"]=L["Top Left"], 
			["BOTTOMLEFT"]=L["Bottom Left"], 
			["TOPRIGHT"]=L["Top Right"], 
			["BOTTOMRIGHT"]=L["Bottom Right"], 
		}
	end,
	set = function(info,val) 
		P.plateAnchorPoint = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.plateAnchorPoint end
}

defaultSettings.profile.barOffsetX		= 0
CoreOptionsTable.args.bar.args.barOffsetX = {
	name = L["Bar X Offset"],
	desc = L["Left to right offset."],
	type = "range",
	order	= 5,
	min		= -100,
	max		= 100,
	step	= 1,
	set = function(info,val) 
		P.barOffsetX = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.barOffsetX end
}

defaultSettings.profile.barOffsetY		= 8 --bit north incase user's running Threat plates.
CoreOptionsTable.args.bar.args.barOffsetY = {
	name = L["Bar Y Offset"],
	desc = L["Up to down offset."],
	type = "range",
	order	= 6,
	min		= -100,
	max		= 100,
	step	= 1,
	set = function(info,val) 
		P.barOffsetY = val
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.barOffsetY end
}

defaultSettings.profile.iconsPerRow		= 6
CoreOptionsTable.args.bar.args.iconsPerRow = {
	name = L["Icons Per Row"],
	desc = L["Number of icons to display per row."],
	type = "range",
	order	= 7,
	min		= 1,
	max		= 16,
	step	= 1,
	set = function(info,val) 
		P.iconsPerRow = val
		core:ResetAllPlateIcons()
--~ 		core:UpdateBarsSize()
		core:ShowAllKnownSpells()
	end,
	get = function(info) return P.iconsPerRow end
}

defaultSettings.profile.rowGroth		= 1
CoreOptionsTable.args.bar.args.rowGroth = {
	name = L["Row Growth"],
	order = 8,
	desc = L["Which way do the rows grow, up or down."],
	type = "select",
	
	values = function()
		return {
			L["Up"],
			L["Down"],
		}
	end,
	set = function(info,val) 
		P.rowGroth = val
--~ 		core:ResetAllPlateIcons()
		core:ResetAllBarPoints()
	end,
	get = function(info) return P.rowGroth end
}

defaultSettings.profile.numRows		= 2
CoreOptionsTable.args.bar.args.numRows = {
	name = L["Max rows"],
	desc = L["Max number of rows to show."],
	type = "range",
	order	= 9,
	min		= 1,
	max		= 4,
	step	= 1,
	set = function(info,val) 
		P.numRows = val
		core:ResetAllPlateIcons()
--~ 		core:UpdateBarsSize()
		core:UpdateBarsBackground()
		core:ShowAllKnownSpells()
	end,
	get = function(info) return P.numRows end
}


defaultSettings.profile.iconSize		= 24
CoreOptionsTable.args.bar.args.iconSize = {
	name = L["Icon Size"],
	desc = L["Size of the icons."],
	type = "range",
	order	= 10,
	min		= 16,
	max		= 60,
	step	= 4,
	set = function(info,val) 
		P.iconSize = val
		core:ResetIconSizes()
--~ 		core:UpdateBarsSize()
	end,
	get = function(info) return P.iconSize end
}

defaultSettings.profile.biggerSelfSpells		= true
CoreOptionsTable.args.bar.args.biggerSelfSpells = {
	name = L["Larger self spells"],
	desc = L["Make your spells 20% bigger then other's."],
	type = "toggle",
	order	= 11,
	set = function(info,val) 
		P.biggerSelfSpells = val
	end,
	get = function(info) return P.biggerSelfSpells end
}

defaultSettings.profile.showCooldown		= true
CoreOptionsTable.args.bar.args.showCooldown = {
	name = L["Show cooldown"],
	desc = L["Show cooldown text under the spell icon."],
	type = "toggle",
	order	= 12,
	set = function(info,val) 
		P.showCooldown = val
--~ 		core:ResetCooldownSize()
--~ 		core:ResetAllPlateIcons()
		core:ResetIconSizes()--Adjust the frame height with the new cooldown size
--~ 		core:UpdateBarsSize()
		core:ShowAllKnownSpells()
	end,
	get = function(info) return P.showCooldown end
}




defaultSettings.profile.cooldownSize		= 10
CoreOptionsTable.args.bar.args.cooldownSize = {
	name = L["Cooldown Size"],
	desc = L["Text size"],
	type = "range",
	order	= 13,
	min		= 6,
	max		= 20,
	step	= 1,
	set = function(info,val) 
		P.cooldownSize = val
		
		core:ResetCooldownSize()
		core:ResetAllPlateIcons()
		core:ResetIconSizes()--Adjust the frame height with the new cooldown size
--~ 		core:UpdateBarsSize()
		core:ShowAllKnownSpells()
	end,
	get = function(info) return P.cooldownSize end
}

defaultSettings.profile.stackSize		= 10
CoreOptionsTable.args.bar.args.stackSize = {
	name = L["Stack Size"],
	desc = L["Text size"],
	type = "range",
	order	= 14,
	min		= 6,
	max		= 20,
	step	= 1,
	set = function(info,val) 
		P.stackSize = val
		core:ResetStackSizes()
	end,
	get = function(info) return P.stackSize end
}

--testing stuff
CoreOptionsTable.args.bar.args.showBarBackground = {
	name = L["Show bar background"],
	desc = L["Show the area where spell icons will be. This is to help you configure the bars.\nThis option won't be saved at logout."],
	type = "toggle",
	order	= 99,
	set = function(info,val) 
		core.showBarBackground = val
		core:UpdateBarsBackground()
	end,
	get = function(info) return core.showBarBackground end
}

CoreOptionsTable.args.bar.args.iconTestMode = {
	name = L["Test Mode"],
	desc = L["For each spell on someone, multiply it by the number of Icons Per Row.\nThis option won't be saved at logout."],
	type = "toggle",
	order	= 100,
	set = function(info,val) 
		core.iconTestMode = val
	end,
	get = function(info) return core.iconTestMode end
}

-- END OF BAR



core.CoreOptionsTable = CoreOptionsTable